/***********************************************************************************
* Copyright: SmartRay GmbH
* Buergermeister-Finsterwalder-Ring 12
* 82515 Wolfratshausen (http://www.smartray.de)
*
* SmartRayApiDemoDlg.h:
*
* @version 3.5.0
************************************************************************************/
#pragma once
#include <string>
#include <algorithm>
#include "afxwin.h"
#include "afxcmn.h"
#include "AdvancedButton.h"

/**************************************************************************
* class: CSmartRayApiDemoDlg
* Contain dialog functions of API demo
* See SmartRayApiDemoDlg.cpp for the implementation of this class
*
**/

class CSmartRayApiDemoDlg : public CDialog
{
// Construction
public:

	/**************************************************************************
	* ctor: CSMartRayApiDemoDlg
	* class standard constructor
	*
	**/
	CSmartRayApiDemoDlg(CWnd* pParent = NULL);

	virtual ~CSmartRayApiDemoDlg();

	// Dialog Data
	enum { IDD = IDD_SMARTRAYAPIDEMO_DIALOG };
		

protected:
	/**************************************************************************
	* Method:    DoDataExchange
	* Called by the framework to exchange and validate dialog data.
	* @param pDx a pointer to a CDataExchange object.
	*
	**/
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV support


// Implementation
protected:
	HICON m_hIcon;

	// Generated message map functions
	virtual BOOL OnInitDialog();
	afx_msg void OnPaint();
	afx_msg HCURSOR OnQueryDragIcon();
	afx_msg void OnTimer(UINT_PTR nIDEvent);
	DECLARE_MESSAGE_MAP()
	 

private:
	CButton m_startButton;
	CButton m_stopButton;
	CButton m_remapButton;
	CButton m_doubleExpButton;
	CEdit m_offsetZEdit;
	CEdit m_scaleZEdit;
	CEdit m_camRangeMinEdit;
	CEdit m_camRangeMaxEdit;
	CEdit m_secondExpEdit;
	CAdvancedButton adBtnConnect;
	CAdvancedButton adBtnAlive;
	CAdvancedButton adBtnError;
	CAdvancedButton adBtnLaserlight;
	CAdvancedButton adBtnIn0;
	CAdvancedButton adBtnIn1;
	CAdvancedButton adBtnIn2;
	CAdvancedButton adBtnIn3;
	CAdvancedButton adBtnOut0;
	CAdvancedButton adBtnOut1;

	CString m_strText;
	CListBox m_ctrlMessageBox;
	CString m_strAPIVersion;
	CButton m_ctrlClearError;

	CString m_strSerialstr;
	CString m_strMacstr;
	CString m_strPartnumber;
	CString m_strVersion_hw;
	CString m_strVersion_sw;
	bool m_isSensorRunning;
	bool m_isReadRoi;
	int m_roiTimer;
	int m_iNumFrames;
	int m_iLaserStatus;
	int m_iFPS;
	int m_iWidth;
	int m_iHeight;
	int m_roiWidth;
	int m_roiHeight;
	int m_startX;
	int m_startY;
	int m_setDoubleExp;
	int m_firstExpTime;
	int m_secondExpTime;
	float m_camRangeMin;
	float m_camRangeMax;
	float m_scaleZ;
	float m_offsetZ;


public:

	/**************************************************************************
	* Method:    OnBnClickedClearerror
	* Clear the error LED 
	* 
	**/
	afx_msg void OnBnClickedClearerror();

	/**************************************************************************
	* Method:    OnBnClickedLaserstatus
	* Enable the laser
	* 
	**/
	afx_msg void OnBnClickedLaserstatus();

	/**************************************************************************
	* Method:    OnBnClickedUpdate
	* Update the sensor data by reading a new .fup or .aup file
	* 
	**/
	afx_msg void OnBnClickedUpdate();

	/**************************************************************************
	* Method:    OnBnClickedLoadparam
	* Load a new parameter set by reading a new .par file
	* 
	**/
	afx_msg void OnBnClickedLoadparam();

	/**************************************************************************
	* Method:    OnBnClickedStar
	* Star the demo
	* 
	**/
	afx_msg void OnBnClickedStart();

	/**************************************************************************
	* Method:    OnBnClickedStop
	* Stop the demo
	* 
	**/
	afx_msg void OnBnClickedStop();

	/**************************************************************************
	* Method:    OnBnClickedGetserial
	* Get the serial number of the sensor
	* 
	**/
	afx_msg void OnBnClickedGetserial();

	/**************************************************************************
	* Method:    OnBnClickedGetmac
	* Get the Mac address of the sensor
	* 
	**/
	afx_msg void OnBnClickedGetmac();

	/**************************************************************************
	* Method:    OnBnClickedGetpart
	* Get the part number(camera model) of the sensor
	* 
	**/
	afx_msg void OnBnClickedGetpart();

	/**************************************************************************
	* Method:    OnBnClickedGetcamversion
	* Get the version of the sensor 
	* 
	**/
	afx_msg void OnBnClickedGetcamversion();

	/**************************************************************************
	* Method:    OnBnClickedGetsize
	*  Get the image size of the sensor
	* 
	**/
	afx_msg void OnBnClickedGetsize();

	/**************************************************************************
	* Method:    OnBnClickedButton1
	* Connect to the SmartRay GmbH homepage
	* 
	**/
	afx_msg void OnBnClickedButton1();

	/**************************************************************************
	* Method:    OnBnClickedLoadlut
	* Load the look up table (LUT) file to the camera
	* 
	**/
	afx_msg void OnBnClickedLoadlut();

	/**************************************************************************
	* Method:    OnBnClickedCheckremapper
	* Enable/Disable the transformation between world and camera coordinate option
	* 
	**/
	afx_msg void OnBnClickedCheckremapper();
	
	/**************************************************************************
	* Method:    OnBnClickedApplybutton
	* Apply the remapper, region of interest and exposure time parameters to the 
	* current image
	* 
	**/
	afx_msg void OnBnClickedApplybutton();

	
	/**************************************************************************
	* Method:    OnBnClickedCheckdoubleexp
	* Enable/disable the double exposure time
	*
	**/
	afx_msg void OnBnClickedCheckdoubleexp();
};





